@@ -32,7 +32,7 @@ class PartnerClient(object):
     
     def create_user(self, first_name, last_name, dob, email, city, country,
                     avatar_first_name, avatar_last_name_id=None, avatar_last_name=None,
-                    existing_avatar=False):
+                    existing_avatar=False, password=None):
         """Creates a new user. Returns the user details on successful completion
         and raises ApiError when registration fails."""
         
@@ -49,7 +49,10 @@ class PartnerClient(object):
                   'email': email,
                   'city': city,
                   'country_code': country}        
-
+        
+        if password:
+            params['password'] = password
+        
         if existing_avatar:
             params['existing_avatar'] = str(existing_avatar)
             params['avatar_last_name'] = avatar_last_name
